@@ -4,7 +4,7 @@ use crate::GenericEvent;
 /// Axis event
 ///
 /// This event is wrapped with mappings for a specific device.
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 pub struct AxisEvent {
 	axis: AbsoluteAxis,
 	is_synthetic: bool,
