@@ -1,7 +1,7 @@
 use sys::{JS_CORR_BROKEN, JS_CORR_NONE};
 
 /// Correction type
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 #[repr(u16)]
 pub enum CorrectionType {
 	/// The axis needs correction
