@@ -9,7 +9,7 @@ use crate::{EventType, GenericEvent};
 ///
 /// Events lack device context and as a result doesn't provide axis/button mapping. If the mapping is required the event
 /// can be mapped using [`DeviceEvent`](enum.DeviceEvent.html) or manually.
-#[derive(Clone, Copy)]
+#[derive(Clone, Copy, Eq, Hash, PartialEq)]
 pub struct Event {
 	pub(crate) event: js_event,
 }
