@@ -11,7 +11,7 @@ use input_event_codes::{ABS_CNT, BTN_MISC, KEY_CNT};
 use libc::read;
 use nix::errno::Errno;
 
-use crate::event_codes::{AbsoluteAxis, KeyOrButton};
+use crate::event_codes::{AbsoluteAxis, Key};
 use crate::ioctl::{
 	jsiocgaxes, jsiocgaxmap, jsiocgbtnmap, jsiocgbuttons, jsiocgcorr, jsiocgname, jsiocgversion, jsiocsaxmap,
 	jsiocsbtnmap, jsiocscorr,
@@ -40,8 +40,8 @@ pub fn get_button_count(fd: RawFd) -> Result<u8> {
 }
 
 /// Retrieve buttons mapping. Calls `JSIOCGBTNMAP` ioctl.
-pub fn get_button_mapping(fd: RawFd) -> Result<Vec<KeyOrButton>> {
-	let mut result = vec![KeyOrButton::default(); (KEY_CNT - BTN_MISC) as usize];
+pub fn get_button_mapping(fd: RawFd) -> Result<Vec<Key>> {
+	let mut result = vec![Key::default(); (KEY_CNT - BTN_MISC) as usize];
 	unsafe { jsiocgbtnmap(fd, result.as_mut_ptr() as *mut _) }?;
 	Ok(result)
 }
@@ -99,7 +99,7 @@ pub fn set_axis_mapping(fd: RawFd, mapping: &[AbsoluteAxis; ABS_CNT as usize]) -
 }
 
 /// Set buttons mapping. Calls `JSIOCSBTNMAP` ioctl.
-pub fn set_button_mapping(fd: RawFd, mapping: &[KeyOrButton; (KEY_CNT - BTN_MISC) as usize]) -> Result<()> {
+pub fn set_button_mapping(fd: RawFd, mapping: &[Key; (KEY_CNT - BTN_MISC) as usize]) -> Result<()> {
 	unsafe { jsiocsbtnmap(fd, mapping as *const _ as *const _) }?;
 	Ok(())
 }
